@@ -8,10 +8,10 @@ if (
     app.document$.subscribe(function() {
         var nodes = document.querySelectorAll('.timeago');
         var locale = nodes[0].getAttribute('locale');
-        timeago().render(nodes, locale);
+        timeago.render(nodes, locale);
     })
 } else {
      var nodes = document.querySelectorAll('.timeago');
      var locale = nodes[0].getAttribute('locale');
-     timeago().render(nodes, locale);
+     timeago.render(nodes, locale);
 }
\ No newline at end of file
